<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="1.0"
	xmlns:xsl="http://www.w3.org/1999/XSL/Transform"

	xmlns:java="http://xml.apache.org/xslt/java"
	xmlns:util="xalan://org.greenstone.gsdl3.util.XSLTUtil"
	xmlns:gslib="http://www.greenstone.org/skinning"
	xmlns:gsf="http://www.greenstone.org/greenstone3/schema/ConfigFormat"
	
	xmlns:lxslt="http://xml.apache.org/xslt"
	xmlns:result="http://www.example.com/results"
	xmlns:exsl="http://exslt.org/common"

	extension-element-prefixes="java util result exsl"
	exclude-result-prefixes="util java util gsf gslib">

	<xsl:include href="header.xsl"/>
	<xsl:include href="formatmanager.xsl"/>
	

	<!-- put the URL or path of your site here site -->
	<!-- eg 'http://www.example.com/mysite' or '/mysite'  -->
	<xsl:template name="siteURL"><xsl:value-of select="/page/pageResponse/metadataList/metadata[@name='siteURL']"/></xsl:template>


	<!-- the output format for this layout is html -->
	<xsl:output method="html" omit-xml-declaration="yes"/> 

	<xsl:template match="/">
		<xsl:call-template name="mainTemplate"/>
	</xsl:template>
	
	<!-- the main layout is defined here -->
	<xsl:template name="mainTemplate">

		<html>
			<head>
				<!-- ***** in header.xsl ***** -->
				<xsl:call-template name="create-html-header"/>
				<xsl:call-template name="basketHeadTags"/>	
			</head>
			<body>
				<xsl:call-template name="textDirectionAttribute"/>
				<xsl:call-template name="actionClass"/>
				<!--<xsl:call-template name="displayErrorsIfAny"/>-->
				<xsl:call-template name="nav-bar"/>
				<div class="container">
					<a name="top"><xsl:text> </xsl:text></a>
					<div id="topArea">
						<div id="breadcrumbs"><xsl:call-template name="breadcrumbs"/><xsl:text> </xsl:text></div>
						<!-- ***** in header.xsl silenciado*****
						<xsl:call-template name="home-help-preferences"/>
						-->
					</div>
					<div id="container">
						<!-- ***** in header.xsl ***** -->
						<xsl:call-template name="create-banner"/>
						
						<xsl:if test="/page/pageRequest/paramList/param[(@name='formatedit') and (@value='on')]">
							<xsl:call-template name="formatmanagerpre"/>
						</xsl:if>
						<!-- IMPORTANT: when copying this file to base your own custom interface's main.xsl on this one,
						     or when writing a main.xsl for your custom interface from scratch,
						     it is absolutely crucial to ensure the div element containing the xsl:apply-templates for /page
						     is given the id="gs_content".
						     Without this, many parts of GS3 will fail as they make use of gs_content whenever they make
						     calls to the GS server that include 'excerptid=gs_content' in the URL params.
						     For instance, connecting a client-GLI to a remote GS3 server and attempting to view
						     collections will fail as the user groups for a user will return null without this.
						     ADDITIONAL NOTE: it has not been investigated whether adding addition html elements inside the
						     div with id="gs_content" is wise. I've not checked whether such elements will be parsed out
						     properly and just the expected portions retrieved successfully by callers that requested
						     excerptid=gs_content.
						-->
						<div id="gs_content">
							<!--
								show the content of the page.
								to customise this part, edit the xsl file for the page you want to edit
							-->
							<xsl:apply-templates select="/page"/>
						</div>
						<xsl:call-template name="gs_footer"/>
					</div>
				</div>
				<script type="text/javascript" src="interfaces/{$interface_name}/style/bootstrap-5.0.0-beta2/dist/js/bootstrap.bundle.min.js"><xsl:text> </xsl:text></script>
			</body>
		</html>
	</xsl:template>

	<!-- default is to have nothing inthea rightSidebar -->
	<xsl:template name="floatRightSidebar">
	  <div id="float-anchor" style="">
            <xsl:call-template name="rightSidebar"/>
            <xsl:text> </xsl:text>
	  </div>
	</xsl:template>

	<!-- Default rule is to be empty => no rightSidebar to show -->
	<!-- Gets overridden in pages such as query.xsl and classifier.xsl to display baskets and facet info elements -->
	<xsl:template name="rightSidebar">
	</xsl:template>
	
	<!-- Barra de navegación. -->
	<xsl:template name="nav-bar">
		<nav class="navbar navbar-expand-lg navbar-light" style="background-color: #e3f2fd;">
			<div class="container">
				<a class="navbar-brand">
					<xsl:attribute name="href"><xsl:value-of select="$library_name"/>/home</xsl:attribute>
					<img alt="Biblioteca Digitl de la Facultad de Agronomia - UBA" height="48" class="d-inline-block align-text-top">
						<xsl:attribute name="src">interfaces/default/images/FAUBA-icon.png</xsl:attribute>

					</img>
				</a>
				<div class="d-flex flex-column">
					<span class="fs-5" style="color:#0083c6;">Biblioteca Digital</span>
					<span class="text-secondary fs-6">Repositorio Institucional Científico y Académico</span>
				</div>
				<button class="navbar-toggler" type="button" data-bs-toggle="collapse" data-bs-target="#navbarSupportedContent" aria-controls="navbarSupportedContent" aria-expanded="false" aria-label="Toggle navigation">
				 <span class="navbar-toggler-icon"><xsl:text> </xsl:text></span>
				</button>
				<div class="collapse navbar-collapse" id="navbarSupportedContent">
					<ul class="navbar-nav w-100 justify-content-end mb-2 mb-lg-0">
					<xsl:choose>
						<xsl:when test="/page/pageRequest[(@action='p')]">
						<li class="nav-item me-5">
							<a class="nav-link">
								<xsl:attribute name="href"><xsl:value-of select="$library_name"/>/page/biblioteca#section1</xsl:attribute>
								FAUBA Digital
							</a>
						</li>
						<li class="nav-item me-5">
							<a class="nav-link" target="_blank" href="https://www.agro.uba.ar/biblioteca/fauba-digital-repositorio-institucional-cient-fico-y-acad-mico-de-la-facultad-de-agronom">
								Subir Archivos
							</a>
						</li>
						<li class="nav-item me-5">
							<a class="nav-link">
								<xsl:attribute name="href"><xsl:value-of select="$library_name"/>/page/biblioteca#section4</xsl:attribute>
								Derechos de Autor
							</a>
						</li>
						</xsl:when>
					</xsl:choose>

						<li class="nav-item dropdown">
							<a class="nav-link dropdown-toggle" href="https://www.google.com" id="navbarDropdown" role="button" data-bs-toggle="dropdown" aria-expanded="false">
								Colecciones
							</a>
							<ul class="dropdown-menu" aria-labelledby="navbarDropdown">
								<li>
									<a class="dropdown-item">
									<xsl:attribute name="href"><xsl:value-of select="$library_name"/>/collection/tesis/browse/CL1</xsl:attribute>
										Tesis y trabajos finales de posgrado
									</a>
								</li>
								<li>
									<a class="dropdown-item">
									<xsl:attribute name="href"><xsl:value-of select="$library_name"/>/collection/ti/browse/CL1</xsl:attribute>
										Tesis y trabajos finales de grado
									</a>
								</li>
								<li>
									<a class="dropdown-item">
									<xsl:attribute name="href"><xsl:value-of select="$library_name"/>/collection/arti/browse/CL1</xsl:attribute>
										Artículos y capítulos
									</a>
								</li>
								<li>
									<a class="dropdown-item">
									<xsl:attribute name="href"><xsl:value-of select="$library_name"/>/collection/raya/browse/CL1</xsl:attribute>
										Agronomía y Ambiente
									</a>
								</li>
								<li>
									<a class="dropdown-item">
									<xsl:attribute name="href"><xsl:value-of select="$library_name"/>/collection/rfa/browse/CL1</xsl:attribute>
										Revista de la Facultad
									</a>
								</li>
								<li>
									<a class="dropdown-item">
									<xsl:attribute name="href"><xsl:value-of select="$library_name"/>/collection/libros/browse/CL1</xsl:attribute>
										Libros de la EFA en acceso abierto
									</a>
								</li>
								<li>
									<a class="dropdown-item">
									<xsl:attribute name="href"><xsl:value-of select="$library_name"/>/collection/programas/browse/CL1</xsl:attribute>
										Programas de asignaturas
									</a>
								</li>
							</ul>
						</li>
					</ul>
				</div>
			</div>
		</nav>
	</xsl:template>

	<!-- Template controlling the footer. -->
	<xsl:template name="gs_footer">
		<div id="gs_footer" class="border-top mt-5">
			<div class="d-flex flex-row">
				<div class="p-2 flex-fill mt-3">
					<h4>Contacto</h4>
					<div class="ms-5">
					<p>
						Facultad de Agronomía – UBA<br/>
						Av. San Martín 4453 - CP1417 – CABA – Argentina<br/>
					</p>
					<p>
						Sala de lectura de Planta Baja: <a href="mailto:bibliote@agro.uba.ar" rel="noopener" target="_blank">bibliote@agro.uba.ar</a> (54 11) 5287-0013<br/>
						Referencia: <a href="mailto:referen@agro.uba.ar" rel="noopener" target="_blank">bibliote@agro.uba.ar</a> (54 11) 5287-0418<br/>
						Hemeroteca: <a href="mailto:hemerote@agro.uba.ar" rel="noopener" target="_blank">bibliote@agro.uba.ar</a> (54 11) 5287-0218 <br/>
					</p>
					</div>
				</div>
				<div class="p-2 flex-fill mt-3">
					<h4>Seguinos en:</h4>
					<div class="d-flex flex-row ms-5 mt-3">
						<a class="text-white me-2" href="https://www.facebook.com/BibliotecaCentralFauba" target="_blank;" title="Facebook">
							<div class="rounded-circle bg-primary p-3">
								<span class="fab fa-facebook-f" style="width:15px; height:15px"><xsl:text> </xsl:text></span>
							</div>
						</a>
						<a class="text-white me-2" href="https://twitter.com/FAUBA_oficial" target="_blank;" title="Twitter">
							<div class="rounded-circle bg-primary p-3">
								<span class="fab fa-twitter" style="width:15px; height:15px"><xsl:text> </xsl:text></span>
							</div>
						</a>
						<a class="text-white" href="https://www.youtube.com/c/FAUBAcomunicacion/featured" target="_blank;" title="Youtube">
							<div class="rounded-circle bg-primary p-3">
								<span class="fab fa-youtube" style="width:15px; height:15px"><xsl:text> </xsl:text></span>
							</div>
						</a>
					</div>
				</div>
			</div>
		</div>
	</xsl:template>
	
	
	
</xsl:stylesheet>
