<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="1.0"
	xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
	xmlns:java="http://xml.apache.org/xslt/java"
	xmlns:util="xalan://org.greenstone.gsdl3.util.XSLTUtil"
	xmlns:gslib="http://www.greenstone.org/skinning"
	extension-element-prefixes="java util"
	exclude-result-prefixes="java util xsl gslib">

  <xsl:variable name="groupPath"><xsl:value-of select="/page/pageRequest/paramList/param[@name='group']/@value"/></xsl:variable>

  
	<!-- use the 'main' layout -->
	<xsl:include href="layouts/main.xsl"/>

	<!-- set page title -->
	<xsl:template name="pageTitle"><xsl:choose><xsl:when test="$groupPath != ''"><gslib:groupName path="{$groupPath}"/></xsl:when><xsl:otherwise><gslib:siteName/></xsl:otherwise></xsl:choose></xsl:template>

	<!-- set page breadcrumbs -->
	<xsl:template name="breadcrumbs">
		<xsl:if test="$groupPath != ''">
			<gslib:siteLink/>
			<xsl:for-each select="/page/pageResponse/pathList/group">
				<xsl:sort data-type="number" select="@position"/>
				<gslib:rightArrow/>
				<xsl:if test="position() != last()">
				  <!-- don't want the current group in the breadcrumbs -->
				  <a>
				    <xsl:attribute name="href"><gslib:groupHref path="{@path}"/></xsl:attribute>				
				    <xsl:attribute name="title"><gslib:groupName path="{@path}"/></xsl:attribute>
				    <gslib:groupName path="{@path}"/>
				  </a>
				</xsl:if>
			</xsl:for-each>
		</xsl:if>
	</xsl:template>

	<!-- the page content -->
	<xsl:template match="/page/pageResponse">
		<xsl:variable name="sumaTodo" select="
		number(/page/pageResponse/collectionList/collection[@name='arti']/metadataList/metadata[@name='numDocs']) + 
		number(/page/pageResponse/collectionList/collection[@name='libros']/metadataList/metadata[@name='numDocs']) + 
		number(/page/pageResponse/collectionList/collection[@name='programas']/metadataList/metadata[@name='numDocs']) + 
		number(/page/pageResponse/collectionList/collection[@name='raya']/metadataList/metadata[@name='numDocs']) + 
		number(/page/pageResponse/collectionList/collection[@name='rfa']/metadataList/metadata[@name='numDocs']) + 
		number(/page/pageResponse/collectionList/collection[@name='tesis']/metadataList/metadata[@name='numDocs']) + 
		number(/page/pageResponse/collectionList/collection[@name='ti']/metadataList/metadata[@name='numDocs'])
		"/>
	<h3 class="text-secondary my-3">Buscar en los <span class="text-primary font-weight-bold"><xsl:value-of select="$sumaTodo"/></span> documentos</h3>
	<div id="quickSearch">
		<form class="row row-cols-lg-auto g-3 align-items-center">
			<xsl:attribute name="action"><xsl:value-of select="$library_name"/>/collection/todo/search/TextQuery</xsl:attribute>
			<input name="qs" value="1" type="hidden"/>
			<input name="rt" value="rd" type="hidden"/>
			<input name="s1.level" value="Doc" type="hidden"/>
			<input name="s1.startPage" value="1" type="hidden"/>
			<div class="col-12">
				<span class="querybox">
					<nobr><input class="form-control" name="s1.query" size="60" type="text" value=""/></nobr>
				</span>
			</div>
			<div class="col-12">
				<span class="textselect">
					<select class="form-select" name="s1.index">
						<option selected="selected" value="ZZ">Todo</option>
						<option value="TX">Texto</option>
						<option value="TT">Título</option>
						<option value="AU">Autor</option>
						<option value="FE">Fecha</option>
						<option value="CL">Colaboradores</option>
						<option value="DE">Tema</option>
					</select>
				</span>
			</div>
			<div class="col-12">
				<input class="btn btn-secondary" id="quickSearchSubmitButton" value="Buscar" type="submit"/>
			</div>
		</form>
	</div>
	<hr/>
	
	<div class="row">
		<div class="col-md-4">
			<h3 class="text-secondary my-3">Colecciones</h3>
			<div class="list-group">
				<a class="list-group-item list-group-item-action list-group-item-primary">
					<xsl:attribute name="href"><xsl:value-of select="$library_name"/>/collection/tesis/browse/CL1</xsl:attribute>
					<div class="d-flex">
						<div class="my-auto me-2"><span class="fas fa-graduation-cap "><xsl:text> </xsl:text></span></div>
						<div>Tesis y trabajos finales de posgrado</div>
						<div class="ms-auto my-auto"><span class="badge bg-secondary"><xsl:value-of select="/page/pageResponse/collectionList/collection[@name='tesis']/metadataList/metadata[@name='numDocs']"/></span></div>
					</div>
				</a>
				<a class="list-group-item list-group-item-action list-group-item-primary">
					<xsl:attribute name="href"><xsl:value-of select="$library_name"/>/collection/ti/browse/CL1</xsl:attribute>
					<div class="d-flex">
						<div class="my-auto me-2"><span class="fas fa-feather fa-fw"><xsl:text> </xsl:text></span></div>
						<div>Tesis y trabajos finales de grado</div>
						<div class="ms-auto my-auto"><span class="badge bg-secondary"><xsl:value-of select="/page/pageResponse/collectionList/collection[@name='ti']/metadataList/metadata[@name='numDocs']"/></span></div>
					</div>
				</a>
				<a class="list-group-item list-group-item-action list-group-item-primary">
					<xsl:attribute name="href"><xsl:value-of select="$library_name"/>/collection/arti/browse/CL1</xsl:attribute>
					<div class="d-flex">
						<div class="my-auto me-2"><span class="far fa-file-alt fa-fw"><xsl:text> </xsl:text></span></div>
						<div>Artículos y capítulos</div>
						<div class="ms-auto my-auto"><span class="badge bg-secondary"><xsl:value-of select="/page/pageResponse/collectionList/collection[@name='arti']/metadataList/metadata[@name='numDocs']"/></span></div>
					</div>
				</a>
				<a class="list-group-item list-group-item-action list-group-item-primary">
					<xsl:attribute name="href"><xsl:value-of select="$library_name"/>/collection/raya/browse/CL1</xsl:attribute>
					<div class="d-flex">
						<div class="my-auto me-2"><span class="fas fa-file-alt fa-fw"><xsl:text> </xsl:text></span></div>
						<div>Agronomía y Ambiente</div>
						<div class="ms-auto my-auto"><span class="badge bg-secondary"><xsl:value-of select="/page/pageResponse/collectionList/collection[@name='raya']/metadataList/metadata[@name='numDocs']"/></span></div>
					</div>
				</a>
				<a class="list-group-item list-group-item-action list-group-item-primary">
					<xsl:attribute name="href"><xsl:value-of select="$library_name"/>/collection/rfa/browse/CL1</xsl:attribute>
					<div class="d-flex">
						<div class="my-auto me-2"><span class="fas fa-book fa-fw"><xsl:text> </xsl:text></span></div>
						<div>Revista de la Facultad de Agronomía</div>
						<div class="ms-auto my-auto"><span class="badge bg-secondary"><xsl:value-of select="/page/pageResponse/collectionList/collection[@name='rfa']/metadataList/metadata[@name='numDocs']"/></span></div>
					</div>
				</a>
				<a class="list-group-item list-group-item-action list-group-item-primary">
					<xsl:attribute name="href"><xsl:value-of select="$library_name"/>/collection/libros/browse/CL1</xsl:attribute>
					<div class="d-flex">
						<div class="my-auto me-2"><span class="fas fa-book fa-fw"><xsl:text> </xsl:text></span></div>
						<div>Libros de la EFA en acceso abierto</div>
						<div class="ms-auto my-auto"><span class="badge bg-secondary"><xsl:value-of select="/page/pageResponse/collectionList/collection[@name='libros']/metadataList/metadata[@name='numDocs']"/></span></div>
					</div>
				</a>
				<a class="list-group-item list-group-item-action list-group-item-primary">
					<xsl:attribute name="href"><xsl:value-of select="$library_name"/>/collection/programas/browse/CL1</xsl:attribute>
					<div class="d-flex">
						<div class="my-auto me-2"><span class="fas fa-book fa-fw"><xsl:text> </xsl:text></span></div>
						<div>Programas de asignaturas</div>
						<div class="ms-auto my-auto"><span class="badge bg-secondary"><xsl:value-of select="/page/pageResponse/collectionList/collection[@name='programas']/metadataList/metadata[@name='numDocs']"/></span></div>
					</div>
				</a>
			</div>
		</div>
		<div class="col-md-8">
			<div id="carouselExampleDark" class="carousel carousel-dark slide mt-3" data-bs-ride="carousel">
				<div class="carousel-inner">
					<div class="carousel-item active">
						<div class="d-flex mx-auto w-75"><h3 class="text-secondary mx-auto">Últimos Libros</h3></div>
						<div class="d-flex mx-auto w-75">
							<div class="ultimosDocs-libro1 flex-column p-2"><xsl:text> </xsl:text></div>
							<div class="ultimosDocs-libro2 flex-column p-2"><xsl:text> </xsl:text></div>
							<div class="ultimosDocs-libro3 flex-column p-2"><xsl:text> </xsl:text></div>
						</div>
					</div>
					<div class="carousel-item">
						<div class="d-flex mx-auto w-75"><h3 class="text-secondary mx-auto">Últimas Tesis de grado</h3></div>
						<div class="d-flex mx-auto w-75">
							<div class="ultimosDocs-tesis1 p-2"><xsl:text> </xsl:text></div>
							<div class="ultimosDocs-tesis2 p-2"><xsl:text> </xsl:text></div>
							<div class="ultimosDocs-tesis3 p-2"><xsl:text> </xsl:text></div>
						</div>
					</div>
					<div class="carousel-item">
						<div class="d-flex mx-auto w-75"><h3 class="text-secondary mx-auto">Últimas Tesis de posgrado</h3></div>
						<div class="d-flex mx-auto w-75">
							<div class="ultimosDocs-ti1 p-2"><xsl:text> </xsl:text></div>
							<div class="ultimosDocs-ti2 p-2"><xsl:text> </xsl:text></div>
							<div class="ultimosDocs-ti3 p-2"><xsl:text> </xsl:text></div>
						</div>
					</div>
					<div class="carousel-item">
						<div class="d-flex mx-auto w-75"><h3 class="text-secondary mx-auto">Últimos Artículos y Capítulos</h3></div>
						<div class="d-flex mx-auto w-75">
							<div class="ultimosDocs-arti1 p-2"><xsl:text> </xsl:text></div>
							<div class="ultimosDocs-arti2 p-2"><xsl:text> </xsl:text></div>
							<div class="ultimosDocs-arti3 p-2"><xsl:text> </xsl:text></div>
						</div>
					</div>
					<div class="carousel-item">
						<div class="d-flex mx-auto w-75"><h3 class="text-secondary mx-auto">Últimos Articulos de Agronomía y Ambiente</h3></div>
						<div class="d-flex mx-auto w-75">
							<div class="ultimosDocs-raya1 p-2"><xsl:text> </xsl:text></div>
							<div class="ultimosDocs-raya2 p-2"><xsl:text> </xsl:text></div>
							<div class="ultimosDocs-raya3 p-2"><xsl:text> </xsl:text></div>
						</div>
					</div>
					<div class="carousel-item">
						<div class="d-flex mx-auto w-75"><h3 class="text-secondary mx-auto">Últimos Articulos de Revista de la Facultad de Agronomía</h3></div>
						<div class="d-flex mx-auto w-75">
							<div class="ultimosDocs-rfa1 p-2"><xsl:text> </xsl:text></div>
							<div class="ultimosDocs-rfa2 p-2"><xsl:text> </xsl:text></div>
							<div class="ultimosDocs-rfa3 p-2"><xsl:text> </xsl:text></div>
						</div>
					</div>
				</div>
				<button class="carousel-control-prev" type="button" data-bs-target="#carouselExampleDark" data-bs-slide="prev">
					<span class="carousel-control-prev-icon" aria-hidden="true"></span>
					<span class="visually-hidden">Previous</span>
				</button>
				<button class="carousel-control-next" type="button" data-bs-target="#carouselExampleDark" data-bs-slide="next">
					<span class="carousel-control-next-icon" aria-hidden="true"></span>
					<span class="visually-hidden">Next</span>
				</button>
			</div>
		</div>
		<div class="py-2 my-2"><xsl:text> </xsl:text></div>
	</div>


	<script type="text/javascript" src="interfaces/{$interface_name}/js/ultimosDocs.js"><xsl:text> </xsl:text></script>



		<!--
		<div id="quickSearch">
			<gslib:crossCollectionQuickSearchForm/>
		</div>

		<h2><gslib:selectACollectionTextBar/></h2>
		<xsl:call-template name="collectionAndGroupLinks"/>

	        <div style="clear: both; padding-top: 4px; padding-bottom: 4px;"><hr/></div>
		<xsl:variable name="siteDesc"><xsl:choose><xsl:when test="$groupPath != ''"><gslib:groupDescription path="{$groupPath}"/></xsl:when><xsl:otherwise><gslib:siteDescription/></xsl:otherwise></xsl:choose></xsl:variable>
		<xsl:if test="$siteDesc != ''">
		  <xsl:value-of select="$siteDesc"/>
		  <div style="clear: both; padding-top: 4px; padding-bottom: 4px;"><hr/></div>
		</xsl:if>
		<gslib:serviceClusterList/>

		<xsl:for-each select="serviceList/service[@type='query']">
			<gslib:serviceLink/><br/>
		</xsl:for-each>
		
		<xsl:for-each select="serviceList/service[@type='authen']">
			<gslib:libraryInterfaceLink/><br/><br/>
			<gslib:authenticationLink/><br/><br/>
			<gslib:depositorTitleMainLink/><br/><br/>
			<gslib:registerLink/><br/><br/>
		</xsl:for-each>

		<gslib:aboutGreenstoneLink/><br/>
		-->
	</xsl:template>

	<xsl:template name="collectionAndGroupLinks">
	  <xsl:for-each select="collectionList/collection|groupList/group">
            <xsl:sort data-type="number" select="@position"/>
	    <xsl:if test="name() = 'collection'">
              <gslib:collectionLinkWithImage/>
	    </xsl:if>
	    <xsl:if test="name() = 'group'">
              <gslib:groupLinkWithImage/>
	    </xsl:if>			
          </xsl:for-each>
	  
	</xsl:template>
	<xsl:template match="/page/xsltparams">
	  <!-- suppress xsltparam block in page -->
	</xsl:template>

</xsl:stylesheet>


